use if ! ( grep { $_ eq '.' } @INC ), qw[lib .];
use lib 'inc';
use Devel::AssertOS qw[Linux];

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.010.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use My::Builder;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::PkgConfig" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Bindings for C<systemd> APIs",
  "dist_author" => [
    "Ioan Rogers <ioanr\@cpan.org>"
  ],
  "dist_name" => "Linux-Systemd",
  "dist_version" => "1.172840",
  "license" => "lgpl",
  "module_name" => "Linux::Systemd",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Exporter" => 0,
    "File::Basename" => 0,
    "Moo" => 0,
    "XSLoader" => 0,
    "perl" => "v5.16.0",
    "strictures" => 2
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::CheckDeps" => "0.010",
    "Test::Fatal" => 0,
    "Test::More" => "0.94",
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::CheckDeps" => "0.010",
  "Test::Fatal" => 0,
  "Test::More" => "0.94",
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = My::Builder->new(%module_build_args);


$build->create_build_script;
